<!--
Copyright (C) 2023 Maxwell G <maxwell@gtmx.me>
SPDX-License-Identifier: GPL-2.0-or-later
-->

# fclogr

[![builds.sr.ht status](https://builds.sr.ht/~gotmax23/fclogr/commits/main.svg)](https://builds.sr.ht/~gotmax23/fclogr/commits/main?)

[![copr build status][badge-copr]][link-copr] (gotmax23/fclogr)

[![copr build status][badge-copr-dev]][link-copr-dev] (gotmax23/fclogr-dev)

fclogr is a tool for managing RPM changelogs and updates

## Links

- [fclogr project hub](https://sr.ht/~gotmax23/fclogr)
- [fclogr git.sr.ht repo](https://git.sr.ht/~gotmax23/fclogr)
- [fclogr tracker](https://todo.sr.ht/~gotmax23/fclogr)
- [fclogr mailing list][archives] ([~gotmax/fclogr@lists.sr.ht][mailto])

[archives]: https://lists.sr.ht/~gotmax23/fclogr
[mailto]: mailto:~gotmax/fclogr@lists.sr.ht

## Contributing

See [CONTRIBUTING.md](https://git.sr.ht/~gotmax23/fclogr/tree/main/item/CONTRIBUTING.md).

## License

This repository is licensed under

    SPDX-License-Identifer: GPL-2.0-or-later

[badge-copr]: https://copr.fedorainfracloud.org/coprs/gotmax23/fclogr/package/fclogr/status_image/last_build.png
[link-copr]: https://copr.fedorainfracloud.org/coprs/gotmax23/fclogr/
[badge-copr-dev]: https://copr.fedorainfracloud.org/coprs/gotmax23/fclogr-dev/package/fclogr/status_image/last_build.png
[link-copr-dev]: https://copr.fedorainfracloud.org/coprs/gotmax23/fclogr-dev/
